@@ -2,10 +2,19 @@ from datetime import datetime
 
 from hdx.data.dataset import Dataset
 
-from hdx.scraper.utilities import get_isodate_from_dataset_date
+from hdx.scraper.utilities import (
+    get_isodate_from_dataset_date,
+    string_params_to_dict,
+)
 
 
 class TestUtils:
+    def test_string_params_to_dict(self):
+        result = string_params_to_dict("a: 123, b: 345")
+        assert result == {"a": "123", "b": "345"}
+        result = string_params_to_dict("a:123,b:345")
+        assert result == {"a": "123", "b": "345"}
+
     def test_get_isodate_from_dataset_date(self, configuration):
         dataset = Dataset(
             {
